@@ -1,7 +1,9 @@
+from typing import List
+
 from objectrest.json_handler import *
 
 
-def _create_object(json_data: dict, model: type):
+def _create_object(json_data: dict, model: type, sub_keys: List = None):
     """
     Parse JSON data into a Pydantic model
 
@@ -9,9 +11,15 @@ def _create_object(json_data: dict, model: type):
     :type json_data:
     :param model:
     :type model:
+    :param sub_keys:
+    :type sub_keys:
     :return:
     :rtype:
     """
+    if sub_keys:
+        for key in sub_keys:
+            json_data = json_data.get(key, {})
+
     if not json_data:
         return None
 
@@ -21,7 +29,7 @@ def _create_object(json_data: dict, model: type):
         return None
 
 
-def get_object(url: str, model: type, session: requests.Session = None, **kwargs):
+def get_object(url: str, model: type, sub_keys: List = None, session: requests.Session = None, **kwargs):
     """
     Parse the JSON data from a GET request into an object
 
@@ -29,6 +37,8 @@ def get_object(url: str, model: type, session: requests.Session = None, **kwargs
     :type url: str
     :param model: a Pydantic model to generate from the response JSON data
     :type model: type
+    :param sub_keys: A list of sub-keys to search for (in order) to find JSON data for model.
+    :type sub_keys: list
     :param session: a requests.Session to use for the API call (optional)
     :type session: requests.Session, optional
     :param kwargs: Keyword arguments to pass to Requests library
@@ -37,10 +47,10 @@ def get_object(url: str, model: type, session: requests.Session = None, **kwargs
     :rtype: object
     """
     json_data = get_json(url=url, session=session, **kwargs)
-    return _create_object(json_data=json_data, model=model)
+    return _create_object(json_data=json_data, model=model, sub_keys=sub_keys)
 
 
-def post_object(url: str, model: type, session: requests.Session = None, **kwargs):
+def post_object(url: str, model: type, sub_keys: List = None, session: requests.Session = None, **kwargs):
     """
     Parse the JSON data from a POST request into an object
 
@@ -48,6 +58,8 @@ def post_object(url: str, model: type, session: requests.Session = None, **kwarg
     :type url: str
     :param model: a Pydantic model to generate from the response JSON data
     :type model: type
+    :param sub_keys: A list of sub-keys to search for (in order) to find JSON data for model.
+    :type sub_keys: list
     :param session: a requests.Session to use for the API call (optional)
     :type session: requests.Session, optional
     :param kwargs: Keyword arguments to pass to Requests library
@@ -56,10 +68,10 @@ def post_object(url: str, model: type, session: requests.Session = None, **kwarg
     :rtype: object
     """
     json_data = post_json(url=url, session=session, **kwargs)
-    return _create_object(json_data=json_data, model=model)
+    return _create_object(json_data=json_data, model=model, sub_keys=sub_keys)
 
 
-def put_object(url: str, model: type, session: requests.Session = None, **kwargs):
+def put_object(url: str, model: type, sub_keys: List = None, session: requests.Session = None, **kwargs):
     """
     Parse the JSON data from a PUT request into an object
 
@@ -67,6 +79,8 @@ def put_object(url: str, model: type, session: requests.Session = None, **kwargs
     :type url: str
     :param model: a Pydantic model to generate from the response JSON data
     :type model: type
+    :param sub_keys: A list of sub-keys to search for (in order) to find JSON data for model.
+    :type sub_keys: list
     :param session: a requests.Session to use for the API call (optional)
     :type session: requests.Session, optional
     :param kwargs: Keyword arguments to pass to Requests library
@@ -75,10 +89,10 @@ def put_object(url: str, model: type, session: requests.Session = None, **kwargs
     :rtype: object
     """
     json_data = put_json(url=url, session=session, **kwargs)
-    return _create_object(json_data=json_data, model=model)
+    return _create_object(json_data=json_data, model=model, sub_keys=sub_keys)
 
 
-def patch_object(url: str, model: type, session: requests.Session = None, **kwargs):
+def patch_object(url: str, model: type, sub_keys: List = None, session: requests.Session = None, **kwargs):
     """
     Parse the JSON data from a PATCH request into an object
 
@@ -86,6 +100,8 @@ def patch_object(url: str, model: type, session: requests.Session = None, **kwar
     :type url: str
     :param model: a Pydantic model to generate from the response JSON data
     :type model: type
+    :param sub_keys: A list of sub-keys to search for (in order) to find JSON data for model.
+    :type sub_keys: list
     :param session: a requests.Session to use for the API call (optional)
     :type session: requests.Session, optional
     :param kwargs: Keyword arguments to pass to Requests library
@@ -94,10 +110,10 @@ def patch_object(url: str, model: type, session: requests.Session = None, **kwar
     :rtype: object
     """
     json_data = patch_json(url=url, session=session, **kwargs)
-    return _create_object(json_data=json_data, model=model)
+    return _create_object(json_data=json_data, model=model, sub_keys=sub_keys)
 
 
-def delete_object(url: str, model: type, session: requests.Session = None, **kwargs):
+def delete_object(url: str, model: type, sub_keys: List = None, session: requests.Session = None, **kwargs):
     """
     Parse the JSON data from a DELETE request into an object
 
@@ -105,6 +121,8 @@ def delete_object(url: str, model: type, session: requests.Session = None, **kwa
     :type url: str
     :param model: a Pydantic model to generate from the response JSON data
     :type model: type
+    :param sub_keys: A list of sub-keys to search for (in order) to find JSON data for model.
+    :type sub_keys: list
     :param session: a requests.Session to use for the API call (optional)
     :type session: requests.Session, optional
     :param kwargs: Keyword arguments to pass to Requests library
@@ -113,4 +131,4 @@ def delete_object(url: str, model: type, session: requests.Session = None, **kwa
     :rtype: object
     """
     json_data = delete_json(url=url, session=session, **kwargs)
-    return _create_object(json_data=json_data, model=model)
+    return _create_object(json_data=json_data, model=model, sub_keys=sub_keys)
